#!/usr/bin/python
# -*- coding: utf-8 -*-

# Hive Appier Framework
# Copyright (c) 2008-2019 Hive Solutions Lda.
#
# This file is part of Hive Appier Framework.
#
# Hive Appier Framework is free software: you can redistribute it and/or modify
# it under the terms of the Apache License as published by the Apache
# Foundation, either version 2.0 of the License, or (at your option) any
# later version.
#
# Hive Appier Framework is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# Apache License for more details.
#
# You should have received a copy of the Apache License along with
# Hive Appier Framework. If not, see <http://www.apache.org/licenses/>.

__author__ = "João Magalhães <joamag@hive.pt>"
""" The author(s) of the module """

__version__ = "1.0.0"
""" The version of the module """

__revision__ = "$LastChangedRevision$"
""" The revision number of the module """

__date__ = "$LastChangedDate$"
""" The last change date of the module """

__copyright__ = "Copyright (c) 2008-2019 Hive Solutions Lda."
""" The copyright for the module """

__license__ = "Apache License, Version 2.0"
""" The license for the module """

import unittest

import appier
import appier_extras

class LocaleTest(unittest.TestCase):

    def setUp(self):
        self.app = appier.App(
            parts = (appier_extras.admin.AdminPart,),
            session_c = appier.MemorySession
        )

    def tearDown(self):
        self.app.unload()
        adapter = appier.get_adapter()
        adapter.drop_db()

    def test_basic(self):
        locale = appier_extras.admin.Locale()
        locale.locale = "en_us"
        locale.data_j = dict(key = "value")
        locale.save()

        self.assertNotEqual(locale.id, None)
        self.assertEqual(locale.locale, "en_us")
        self.assertEqual(locale.data_j, dict(key = "value"))

    def test_variant(self):
        locale = appier_extras.admin.Locale()
        locale.locale = "en_us_academic"
        locale.data_j = dict(key = "value")
        locale.save()

        self.assertNotEqual(locale.id, None)
        self.assertEqual(locale.locale, "en_us_academic")
        self.assertEqual(locale.data_j, dict(key = "value"))

        locale = appier_extras.admin.Locale()
        locale.locale = "en_us_"
        locale.data_j = dict(key = "value")
        self.assertRaises(appier.ValidationError, locale.save)

        locale = appier_extras.admin.Locale()
        locale.locale = "en_us_1"
        locale.data_j = dict(key = "value")
        self.assertRaises(appier.ValidationError, locale.save)



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Hive Appier Framework
# Copyright (c) 2008-2019 Hive Solutions Lda.
#
# This file is part of Hive Appier Framework.
#
# Hive Appier Framework is free software: you can redistribute it and/or modify
# it under the terms of the Apache License as published by the Apache
# Foundation, either version 2.0 of the License, or (at your option) any
# later version.
#
# Hive Appier Framework is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# Apache License for more details.
#
# You should have received a copy of the Apache License along with
# Hive Appier Framework. If not, see <http://www.apache.org/licenses/>.

__author__ = "João Magalhães <joamag@hive.pt>"
""" The author(s) of the module """

__version__ = "1.0.0"
""" The version of the module """

__revision__ = "$LastChangedRevision$"
""" The revision number of the module """

__date__ = "$LastChangedDate$"
""" The last change date of the module """

__copyright__ = "Copyright (c) 2008-2019 Hive Solutions Lda."
""" The copyright for the module """

__license__ = "Apache License, Version 2.0"
""" The license for the module """

import appier

class Twitter(object):

    def ensure_twitter(self):
        appier.ensure_pip("twitter", package = "twitter_api")

    def has_twitter(self):
        try: import twitter
        except Exception: twitter = None
        if not twitter: return False
        if not appier.conf("TWITTER_KEY"): return False
        if not appier.conf("TWITTER_SECRET"): return False
        return True

    def ensure_twitter_account(self, create = True, safe = True):
        api = self.get_twitter_api()
        user = api.verify_account()
        email = "%s@twitter.com" % user["screen_name"]
        twitter_username = user["screen_name"]
        account = self.owner.admin_account.get(
            twitter_username = twitter_username,
            rules = False,
            raise_e = False
        )
        account = account or self.owner.admin_account.from_session()
        account = account or self.owner.admin_account.get(
            email = email,
            rules = False,
            raise_e = False
        )

        if safe and "tw.oauth_token" in self.session:
            del self.session["tw.oauth_token"]
        if safe and "tw.oauth_token_secret" in self.session:
            del self.session["tw.oauth_token_secret"]
        if safe and "tw.oauth_temporary" in self.session:
            del self.session["tw.oauth_temporary"]

        if not account:
            if not create: raise appier.NotFoundError(
                message = "No account found for Twitter account"
            )

            account = self.owner.admin_account(
                username = twitter_username,
                email = email,
                password = api.oauth_token,
                password_confirm = api.oauth_token,
                twitter_username = twitter_username,
                twitter_token = api.oauth_token,
                type = self.owner.admin_account.USER_TYPE
            )
            account.save()
            account = account.reload(rules = False)

        if not account.twitter_username:
            account.twitter_username = twitter_username
            account.twitter_token = api.oauth_token
            account.save()

        if not account.twitter_token == api.oauth_token:
            account.twitter_token = api.oauth_token
            account.save()

        account.touch_login_s()
        account._set_account()

        return account

    def unset_twitter_account(self):
        account = self.owner.admin_account.from_session()
        account.twitter_username = None
        account.twitter_token = None
        account.save()

    def ensure_twitter_api(self, state = None, refresh = False):
        oauth_token = self.session.get("tw.oauth_token", None)
        oauth_token_secret = self.session.get("tw.oauth_token_secret", None)
        oauth_temporary = self.session.get("tw.oauth_temporary", True)
        if not oauth_temporary and oauth_token and\
            oauth_token_secret and not refresh: return
        self.session["tw.oauth_token"] = None
        self.session["tw.oauth_token_secret"] = None
        self.session["tw.oauth_temporary"] = True
        api = self.get_twitter_api()
        url = api.oauth_authorize(state = state)
        self.session["tw.oauth_token"] = api.oauth_token
        self.session["tw.oauth_token_secret"] = api.oauth_token_secret
        self.session["tw.oauth_temporary"] = True
        return url

    def get_twitter_api(self):
        import twitter
        redirect_url = self.url_for("admin.oauth_twitter", absolute = True)
        oauth_token = self.session and self.session.get("tw.oauth_token", None)
        oauth_token_secret = self.session and self.session.get("tw.oauth_token_secret", None)
        return twitter.API(
            client_key = appier.conf("TWITTER_KEY"),
            client_secret = appier.conf("TWITTER_SECRET"),
            redirect_url = redirect_url,
            oauth_token = oauth_token,
            oauth_token_secret = oauth_token_secret
        )



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Hive Appier Framework
# Copyright (c) 2008-2019 Hive Solutions Lda.
#
# This file is part of Hive Appier Framework.
#
# Hive Appier Framework is free software: you can redistribute it and/or modify
# it under the terms of the Apache License as published by the Apache
# Foundation, either version 2.0 of the License, or (at your option) any
# later version.
#
# Hive Appier Framework is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# Apache License for more details.
#
# You should have received a copy of the Apache License along with
# Hive Appier Framework. If not, see <http://www.apache.org/licenses/>.

__author__ = "João Magalhães <joamag@hive.pt>"
""" The author(s) of the module """

__version__ = "1.0.0"
""" The version of the module """

__revision__ = "$LastChangedRevision$"
""" The revision number of the module """

__date__ = "$LastChangedDate$"
""" The last change date of the module """

__copyright__ = "Copyright (c) 2008-2019 Hive Solutions Lda."
""" The copyright for the module """

__license__ = "Apache License, Version 2.0"
""" The license for the module """

import appier

from appier_extras.parts.admin.models import base

class Snapshot(base.Base):

    target_id = appier.field(
        type = int,
        index = "all",
        description = "Target ID"
    )
    """ The unique identifier of the entity to be used
    to identify the entity globally (should be unique) """

    target_cls = appier.field(
        index = "hashed",
        description = "Target Class"
    )
    """ The name of the class for the entity (as a string) """

    model_data = appier.field(
        type = dict
    )
    """ The payload information on the entity/model
    data that is going to be used to restore the
    entity back to the original state (if requested) """

    @classmethod
    def validate(cls):
        return super(Snapshot, cls).validate() + [
            appier.not_null("target_id"),

            appier.not_null("target_cls"),
            appier.not_empty("target_cls"),

            appier.not_null("model_data")
        ]

    @classmethod
    def list_names(cls):
        return ["id", "created", "target_id", "target_cls"]

    @classmethod
    def order_name(cls):
        return ["id", -1]

    @classmethod
    def is_indexed(cls):
        return False

    @classmethod
    def create_snapshot(
        cls,
        target_id,
        target_cls,
        model_data
    ):
        snapshot = cls(
            target_id = target_id,
            target_cls = target_cls.__name__,
            model_data = model_data
        )
        snapshot.save()

    def pre_save(self):
        base.Base.pre_save(self)
        self.model_data = self.model_data_b

    @appier.operation(name = "Restore")
    def restore_s(self, save = True, validate = False):
        model_data = dict(self.model_data_s)
        target_cls = appier.get_model(self.target_cls)
        target_cls.types(model_data)
        model = target_cls.old(model = model_data, safe = False)
        if not save: return model
        exists = not target_cls.get(id = self.target_id, raise_e = False) == None
        if save: model.save(
            validate = validate,
            is_new = not exists,
            increment_a = False,
            immutables_a = False
        )
        return model

    @property
    def model_data_s(self):
        """
        Safe version of the model data that should ensure that the
        primary object identifier of the model is properly encoded
        as an object identifier.

        :rtype: Dictionary
        :return: The safe version of the model data, with proper
        object identifiers set.
        """

        cls = self.__class__
        if not "_id" in self.model_data: return self.model_data
        adapter = cls._adapter()
        model_data = dict(self.model_data)
        model_data["_id"] = adapter.object_id(model_data["_id"])
        return model_data

    @property
    def model_data_b(self):
        """
        Bulk version of the model data that should be ready for
        safe data source storing.

        The primary goal is to properly encode the object id of
        the model in a safe "dictionary way".

        :rtype: Dictionary
        :return: The bulk version of the model data, with proper
        object identifiers encoded in "dictionary way".
        """

        cls = self.__class__
        if not "_id" in self.model_data: return self.model_data
        model_data = dict(self.model_data)
        model_data["_id"] = str(model_data["_id"])
        return model_data



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Hive Appier Framework
# Copyright (c) 2008-2019 Hive Solutions Lda.
#
# This file is part of Hive Appier Framework.
#
# Hive Appier Framework is free software: you can redistribute it and/or modify
# it under the terms of the Apache License as published by the Apache
# Foundation, either version 2.0 of the License, or (at your option) any
# later version.
#
# Hive Appier Framework is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# Apache License for more details.
#
# You should have received a copy of the Apache License along with
# Hive Appier Framework. If not, see <http://www.apache.org/licenses/>.

__author__ = "João Magalhães <joamag@hive.pt>"
""" The author(s) of the module """

__version__ = "1.0.0"
""" The version of the module """

__revision__ = "$LastChangedRevision$"
""" The revision number of the module """

__date__ = "$LastChangedDate$"
""" The last change date of the module """

__copyright__ = "Copyright (c) 2008-2019 Hive Solutions Lda."
""" The copyright for the module """

__license__ = "Apache License, Version 2.0"
""" The license for the module """

import unittest

import appier_extras

class MarkdownDebugTest(unittest.TestCase):

    def test_basic(self):
        result = appier_extras.MarkdownDebug.process_str("hello")
        self.assertEqual(result, b"normal")

        result = appier_extras.MarkdownDebug.process_str("**hello**")
        self.assertEqual(result, b"bold")

        result = appier_extras.MarkdownDebug.process_str("hello **world**")
        self.assertEqual(result, b"normal,bold")

    def test_list(self):
        result = appier_extras.MarkdownDebug.process_str("* hello")
        self.assertEqual(result, b"list")

        result = appier_extras.MarkdownDebug.process_str("* hello\n* world")
        self.assertEqual(result, b"list,normal,list")

        result = appier_extras.MarkdownDebug.process_str("1. hello")
        self.assertEqual(result, b"listo")

        result = appier_extras.MarkdownDebug.process_str("1. hello\n2. world")
        self.assertEqual(result, b"listo,normal,listo")

        result = appier_extras.MarkdownDebug.process_str("*\n*\n")
        self.assertEqual(result, b"list,normal,list,normal")

        result = appier_extras.MarkdownDebug.process_str("1.\n2.\n")
        self.assertEqual(result, b"listo,normal,listo,normal")

    def test_image(self):
        result = appier_extras.MarkdownDebug.process_str("![Hello Image](image.jpg)")
        self.assertEqual(result, b"image")

        result = appier_extras.MarkdownDebug.process_str(
            "![Hello Image](image.jpg)",
            options = dict(extended = True)
        )
        self.assertEqual(result, b"image(value=image.jpg)")

    def test_link(self):
        result = appier_extras.MarkdownDebug.process_str("[hello](http://example.com)")
        self.assertEqual(result, b"link")

        result = appier_extras.MarkdownDebug.process_str(
            "[hello](http://example.com)",
            options = dict(extended = True)
        )
        self.assertEqual(result, b"link(value=http://example.com)")

        result = appier_extras.MarkdownDebug.process_str(
            "[hello](http://example.com/page(with_parentheses))",
            options = dict(extended = True)
        )
        if appier_extras.has_regex(): self.assertEqual(result, b"link(value=http://example.com/page(with_parentheses))")
        else: self.assertEqual(result, b"link(value=http://example.com/page(with_parentheses),normal")

        result = appier_extras.MarkdownDebug.process_str(
            "([hello](http://example.com/page))",
            options = dict(extended = True)
        )
        self.assertEqual(result, b"normal,link(value=http://example.com/page),normal")

        result = appier_extras.MarkdownDebug.process_str(
            "[hello[with_parentheses]](http://example.com/page)",
            options = dict(extended = True)
        )
        if appier_extras.has_regex(): self.assertEqual(result, b"link(value=http://example.com/page)")
        else: self.assertEqual(result, b"normal")

        result = appier_extras.MarkdownDebug.process_str(
            "([hellowith_parentheses]](http://example.com/page))",
            options = dict(extended = True)
        )
        self.assertEqual(result, b"normal")

        result = appier_extras.MarkdownDebug.process_str(
            "[![Hello Image](image.jpg)](http://example.com/page)",
            options = dict(extended = True)
        )
        self.assertEqual(result, b"link(value=http://example.com/page)")

    def test_code(self):
        result = appier_extras.MarkdownDebug.process_str("\thello")
        self.assertEqual(result, b"code")

        result = appier_extras.MarkdownDebug.process_str("    hello")
        self.assertEqual(result, b"code")

        result = appier_extras.MarkdownDebug.process_str("    hello\n\tworld")
        self.assertEqual(result, b"code,normal,code")

class MarkdownHTMLTest(unittest.TestCase):

    def test_basic(self):
        result = appier_extras.MarkdownHTML.process_str("hello")
        self.assertEqual(result, b"<p>hello</p>")

        result = appier_extras.MarkdownHTML.process_str("**hello**")
        self.assertEqual(result, b"<strong>hello</strong>")

        result = appier_extras.MarkdownHTML.process_str("hello **world**")
        self.assertEqual(result, b"<p>hello <strong>world</strong></p>")

    def test_list(self):
        result = appier_extras.MarkdownHTML.process_str("* hello")
        self.assertEqual(result, b"<ul><li>hello</li></ul>")

        result = appier_extras.MarkdownHTML.process_str("* hello\n* world")
        self.assertEqual(result, b"<ul><li>hello </li><li>world</li></ul>")

        result = appier_extras.MarkdownHTML.process_str("1. hello")
        self.assertEqual(result, b"<ol><li>hello</li></ol>")

        result = appier_extras.MarkdownHTML.process_str("1. hello\n2. world")
        self.assertEqual(result, b"<ol><li>hello </li><li>world</li></ol>")

        result = appier_extras.MarkdownHTML.process_str("*\n*\n")
        self.assertEqual(result, b"<ul><li> </li><li> </li></ul>")

        result = appier_extras.MarkdownHTML.process_str("1.\n2.\n")
        self.assertEqual(result, b"<ol><li> </li><li> </li></ol>")

    def test_code(self):
        result = appier_extras.MarkdownHTML.process_str("\thello")
        self.assertEqual(result, b"<pre class=\"code language-undefined\">hello</pre>")

        result = appier_extras.MarkdownHTML.process_str("    hello")
        self.assertEqual(result, b"<pre class=\"code language-undefined\">hello</pre>")

        result = appier_extras.MarkdownHTML.process_str("    hello\n\tworld")
        self.assertEqual(result, b"<pre class=\"code language-undefined\">hello\nworld</pre>")



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Hive Appier Framework
# Copyright (c) 2008-2019 Hive Solutions Lda.
#
# This file is part of Hive Appier Framework.
#
# Hive Appier Framework is free software: you can redistribute it and/or modify
# it under the terms of the Apache License as published by the Apache
# Foundation, either version 2.0 of the License, or (at your option) any
# later version.
#
# Hive Appier Framework is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# Apache License for more details.
#
# You should have received a copy of the Apache License along with
# Hive Appier Framework. If not, see <http://www.apache.org/licenses/>.

__author__ = "João Magalhães <joamag@hive.pt>"
""" The author(s) of the module """

__version__ = "1.0.0"
""" The version of the module """

__revision__ = "$LastChangedRevision$"
""" The revision number of the module """

__date__ = "$LastChangedDate$"
""" The last change date of the module """

__copyright__ = "Copyright (c) 2008-2019 Hive Solutions Lda."
""" The copyright for the module """

__license__ = "Apache License, Version 2.0"
""" The license for the module """

import os
import setuptools

setuptools.setup(
    name = "appier_extras",
    version = "0.19.46",
    author = "Hive Solutions Lda.",
    author_email = "development@hive.pt",
    description = "Appier Framework Extra Elements",
    license = "Apache License, Version 2.0",
    keywords = "appier extras framework web json",
    url = "http://appier_extras.hive.pt",
    zip_safe = False,
    packages = [
        "appier_extras",
        "appier_extras.parts",
        "appier_extras.parts.admin",
        "appier_extras.parts.admin.models",
        "appier_extras.parts.admin.models.oauth",
        "appier_extras.parts.admin.partials",
        "appier_extras.parts.admin.social",
        "appier_extras.parts.captcha",
        "appier_extras.parts.contentful",
        "appier_extras.parts.contentful.partials",
        "appier_extras.parts.csfr",
        "appier_extras.parts.diag",
        "appier_extras.parts.diag.models",
        "appier_extras.parts.export",
        "appier_extras.parts.loggly",
        "appier_extras.parts.logstash",
        "appier_extras.parts.opbeat",
        "appier_extras.parts.preflight",
        "appier_extras.parts.prismic",
        "appier_extras.parts.prismic.partials",
        "appier_extras.parts.sematext",
        "appier_extras.test",
        "appier_extras.test.admin",
        "appier_extras.test.admin.models",
        "appier_extras.test.csfr",
        "appier_extras.test.utils",
        "appier_extras.utils"
    ],
    test_suite = "appier_extras.test",
    package_dir = {
        "" : os.path.normpath("src")
    },
    package_data = {
        "appier_extras.parts.admin" : [
            "static/css/*",
            "static/images/*",
            "static/js/*",
            "templates/admin/*",
            "templates/admin/email/*",
            "templates/admin/email/*/*",
            "templates/fluid/*",
            "templates/fluid/*/*",
            "templates/static/*",
            "templates/static/*/*"
        ],
        "appier_extras.parts.captcha" : [
            "static/fonts/*",
            "static/patterns/*"
        ],
        "appier_extras.parts.diag" : [
            "templates/*",
            "templates/*/*"
        ]
    },
    entry_points = {
        "console_scripts" : [
            "markdown = appier_extras.utils.markdown:run"
        ]
    },
    install_requires = [
        "appier"
    ],
    classifiers = [
        "Development Status :: 5 - Production/Stable",
        "Topic :: Utilities",
        "License :: OSI Approved :: Apache Software License",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 2.6",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3.0",
        "Programming Language :: Python :: 3.1",
        "Programming Language :: Python :: 3.2",
        "Programming Language :: Python :: 3.3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7"
    ]
)
